@@ -230,6 +230,10 @@ class Data(Base):
     def baseshape(self):
         return self.shape[:len(self.baseaxes)]
 
+    @property
+    def value_shape(self):
+        return self.shape[len(self.baseaxes):]
+
     @property
     def labels(self):
         return self._labels
@@ -402,7 +406,7 @@ class Data(Base):
 
         return self._constructor(filtered, labels=newlabels).__finalize__(self, noprop=('labels',))
 
-    def _map(self, func, axis=(0,), value_shape=None, dtype=None, with_keys=False):
+    def map(self, func, value_shape=None, dtype=None, with_keys=False):
         """
         Apply an array -> array function across an axis.
 
@@ -429,6 +433,8 @@ class Data(Base):
         with_keys : bool, optional, default=False
             Include keys as an argument to the function
         """
+        axis = self.baseaxes
+
         if self.mode == 'local':
             axes = sorted(tupleize(axis))
             key_shape = [self.shape[axis] for axis in axes]
