@@ -7,7 +7,7 @@ from ..utils import check_spark, check_options
 spark = check_spark()
 
 
-def fromrdd(rdd, dims=None, nrecords=None, dtype=None, labels=None):
+def fromrdd(rdd, dims=None, nrecords=None, dtype=None, labels=None, ordered=False):
     """
     Load images from a Spark RDD.
 
@@ -31,6 +31,9 @@ def fromrdd(rdd, dims=None, nrecords=None, dtype=None, labels=None):
 
     labels : array, optional, default = None
         Labels for records. If provided, should be one-dimensional.
+
+    ordered : boolean, optional, default = False
+        Whether or not the rdd is ordered by key
     """
     from .images import Images
     from bolt.spark.array import BoltArraySpark
@@ -49,7 +52,7 @@ def fromrdd(rdd, dims=None, nrecords=None, dtype=None, labels=None):
             k = (k,)
         return k, v
 
-    values = BoltArraySpark(rdd.map(process_keys), shape=(nrecords,) + tuple(dims), dtype=dtype, split=1)
+    values = BoltArraySpark(rdd.map(process_keys), shape=(nrecords,) + tuple(dims), dtype=dtype, split=1, ordered=ordered)
     return Images(values, labels=labels)
 
 def fromarray(values, labels=None, npartitions=None, engine=None):
@@ -107,6 +110,7 @@ def fromarray(values, labels=None, npartitions=None, engine=None):
         if not npartitions:
             npartitions = engine.defaultParallelism
         values = bolt.array(values, context=engine, npartitions=npartitions, axis=(0,))
+        values._ordered = True
         return Images(values)
 
     return Images(values, labels=labels)
@@ -145,7 +149,7 @@ def fromlist(items, accessor=None, keys=None, dims=None, dtype=None, labels=None
         rdd = engine.parallelize(items, npartitions)
         if accessor:
             rdd = rdd.mapValues(accessor)
-        return fromrdd(rdd, nrecords=nrecords, dims=dims, dtype=dtype, labels=labels)
+        return fromrdd(rdd, nrecords=nrecords, dims=dims, dtype=dtype, labels=labels, ordered=True)
 
     else:
         if accessor:
@@ -207,7 +211,7 @@ def frompath(path, accessor=None, ext=None, start=None, stop=None, recursive=Fal
             data = data.values().zipWithIndex().map(switch)
         else:
             nrecords = reader.nfiles
-        return fromrdd(data, nrecords=nrecords, dims=dims, dtype=dtype, labels=labels)
+        return fromrdd(data, nrecords=nrecords, dims=dims, dtype=dtype, labels=labels, ordered=True)
 
     else:
         if accessor:
